@@ -8,7 +8,16 @@ from ...base import ResponseWithMeta, BaseData
 
 
 class ServicePeriods(Enum):
-    '''Периоды доп. услуг'''
+    '''Периоды доп. услуг.
+
+    Attributes:
+        P1D: 1 день
+        P1M: 1 месяц
+        P3M: 3 месяца
+        P6M: 6 месяцев
+        P1Y: 1 год
+        FOREVER: Вечно
+    '''
     P1D = Period('P1D')
     P1M = Period('P1M')
     P3M = Period('P3M')
@@ -18,7 +27,16 @@ class ServicePeriods(Enum):
 
 
 class DedicatedServerService(BaseData):
-    '''Доп. услуга выделенного сервера'''
+    '''Доп. услуга выделенного сервера.
+
+    Attributes:
+        id (int): UID доп. услуги.
+        price (int): Цена доп. услуги в рублях.
+        period (ServicePeriods): Период доп. услуги.
+        description (str): Описание доп. услуги.
+        short_description (str): Краткое описание доп. услуги.
+        name (str): Название доп. услуги.
+    '''
     id: int = Field(..., description='UID доп. услуги.')
     price: int = Field(..., description='Цена доп. услуги в рублях.')
     period: ServicePeriods = Field(..., description='Период доп. услуги.')
@@ -29,7 +47,11 @@ class DedicatedServerService(BaseData):
 
 
 class DedicatedServerServices(ResponseWithMeta):
-    '''Массив доп. услуг выделенных серверов'''
+    '''Массив доп. услуг выделенных серверов.
+
+    Attributes:
+        dedicated_server_additional_services (list[DedicatedServerService]): Массив доп. услуг выделенных серверов.
+    '''
     dedicated_server_additional_services: list[DedicatedServerService] = Field(
         ..., description='Массив доп. услуг выделенных серверов.'
     )
